aboutsummaryrefslogtreecommitdiff
path: root/libmpio/mpio.h
diff options
context:
space:
mode:
authorgermeier <germeier>2002-10-27 02:45:28 +0000
committergermeier <germeier>2002-10-27 02:45:28 +0000
commit13b7579bd45e89304b8697a6fb471bf0524f49d4 (patch)
treea446bb30895a09bd1ff11a4bfbd5d44de468c102 /libmpio/mpio.h
parent9931f7bb5faf4407bfae23003071a6cb89e79c76 (diff)
downloadmpiosh-13b7579bd45e89304b8697a6fb471bf0524f49d4.tar.gz
mpiosh-13b7579bd45e89304b8697a6fb471bf0524f49d4.tar.bz2
mpiosh-13b7579bd45e89304b8697a6fb471bf0524f49d4.zip
added code to read/write and display config files (CONFIG.DAT and FMCONFIG.DAT)
another 8.3 fix :-(
Diffstat (limited to 'libmpio/mpio.h')
-rw-r--r--libmpio/mpio.h29
1 files changed, 27 insertions, 2 deletions
diff --git a/libmpio/mpio.h b/libmpio/mpio.h
index a36cc49..51decef 100644
--- a/libmpio/mpio.h
+++ b/libmpio/mpio.h
@@ -1,7 +1,7 @@
#/* -*- linux-c -*- */
/*
- * $Id: mpio.h,v 1.10 2002/10/26 13:07:43 germeier Exp $
+ * $Id: mpio.h,v 1.11 2002/10/27 02:45:28 germeier Exp $
*
* Library for USB MPIO-*
*
@@ -75,16 +75,41 @@ BYTE* mpio_dentry_next(mpio_t *, mpio_mem_t, BYTE *);
int mpio_dentry_get(mpio_t *, mpio_mem_t, BYTE *, BYTE *, int,WORD *,
BYTE *, BYTE *, BYTE *, BYTE *, DWORD *);
+/*
+ * reading/writing/deleting of files
+ */
+
/* context, memory bank, filename, callback */
int mpio_file_get(mpio_t *, mpio_mem_t, mpio_filename_t, mpio_callback_t);
/* context, memory bank, filename, callback */
int mpio_file_put(mpio_t *, mpio_mem_t, mpio_filename_t, mpio_filetype_t,
mpio_callback_t);
/* context, memory bank, filename, callback */
int mpio_file_del(mpio_t *, mpio_mem_t, mpio_filename_t, mpio_callback_t);
+/*
+ * reading/writing files into memory (used for config+font files)
+ */
+
+/* context, memory bank, filename, callback, pointer to memory */
+/* the needed memory is allocated and the memory pointer is return */
+/* via the "BYTE **" */
+
+int mpio_file_get_to_memory(mpio_t *, mpio_mem_t, mpio_filename_t,
+ mpio_callback_t, BYTE **);
+
+/* context, memory bank, filename, filetype, callback ... */
+/* ... memory pointer, size of file */
+int mpio_file_put_from_memory(mpio_t *, mpio_mem_t, mpio_filename_t,
+ mpio_filetype_t, mpio_callback_t,
+ BYTE *, int);
+
+/*
+ * formating a memory (internal mem or external SmartMedia card)
+ */
+
/* context, memory bank, callback */
int mpio_memory_format(mpio_t *, mpio_mem_t, mpio_callback_t);
@@ -75,16 +75,41 @@ BYTE* mpio_dentry_next(mpio_t *, mpio_mem_t, BYTE *);
/* context, memory bank, filename, callback */
int mpio_file_get(mpio_t *, mpio_mem_t, mpio_filename_t, mpio_callback_t);
-/* context, memory bank, filename, callback */
+/* context, memory bank, filename, filetype, callback */
int mpio_file_put(mpio_t *, mpio_mem_t, mpio_filename_t, mpio_filetype_t,
mpio_callback_t);